@@ -25,4 +25,17 @@ foreach ($attributes as $key => $values) {
 
 $_SERVER['REMOTE_USER'] = $attributes['seciosssystemid'][0];
 $_SERVER['REMOTE_USER_DATA'] = base64_encode($data);
+
+if ($config->getValue('logout.cookies')) {
+    $loggedin = true;
+    foreach (preg_split('/, */', $config->getValue('logout.cookies')) as $cookie) {
+        if (!isset($_COOKIE[$cookie])) {
+            $loggedin = false;
+            break;
+        }
+    }
+    if ($loggedin) {
+        $_SERVER['REMOTE_USER_LOGGEDIN'] = true;
+    }
+}
 ?>
