@@ -115,6 +115,9 @@ class AutoLogin
             $this->sessioncookie = $options['sessioncookie'];
         }
 
+        if (isset($_GET['url_back'])) {
+            $url['back'] = $_GET['url_back'];
+        }
         if (!isset($url['fatal'])) {
             $url['fatal'] = "/error/HTTP_INTERNAL_SERVER_ERROR.html.var";
         }
@@ -199,6 +202,11 @@ class AutoLogin
      */
     function start()
     {
+        if (isset($_SERVER['REMOTE_USER_LOGGEDIN'])) {
+            header('Location: '.$this->url['back']);
+            return true;
+        }
+
         if (PEAR::isError($rc = $this->login())) {
             $querystr = null;
             if ($this->app) {
@@ -524,8 +532,6 @@ class AutoLogin
             $rc = $this->storage->setPassword($password, $this->app, $init);
             if (PEAR::isError($rc)) {
                 return $rc;
-            } else if ($rc && $pwstrength == false) {
-                return PEAR::raiseError($this->storage->error, AUTO_LOGIN_WEAK_PASSWD_WARN);
             }
         }
 
@@ -568,6 +574,10 @@ class AutoLogin
             }
         }
 
+        if ($rc && $pwstrength == false) {
+            return PEAR::raiseError($this->storage->error, AUTO_LOGIN_WEAK_PASSWD_WARN);
+        }
+
         return $rc;
     }
 
@@ -769,6 +779,7 @@ class AutoLogin
     {
         $object = $this->storage;
 
+        $command = str_replace('\'', '"', $command);
         $command = preg_replace(array('/%u/', '/%p/', '/%o/', '/%P/', '/%O/'),
             array($this->username, $password, $oldpasswd, $object->hashPasswd($password), $object->hashPasswd($oldpasswd)),
                 $command);
@@ -779,6 +790,8 @@ class AutoLogin
                 if (is_array($values)) {
                     $values = join('+', $values);
                 }
+                $values = preg_replace('/(["`\\\\])/', '\\\\$1', $values);
+                $values = str_replace('$', '\\\$', $values);
                 $command = preg_replace('/%{'.$matches[1][$i].'}/', $values, $command);
             }
         }
